@@ -1,13 +1,9 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003      David Hugh-Jones  <hughjonesd@yahoo.co.uk>    *
- *   copyright (C) 2004-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2003 David Hugh-Jones <hughjonesd@yahoo.co.uk>
+    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef PERLWRITER_H
 #define PERLWRITER_H
@@ -41,13 +37,6 @@ public:
     QStringList defaultDatatypes();
 
 private:
-
-    /**
-     * We do not want to write the comment "Private methods" twice
-     * not sure whether this is php specific.
-     */
-    bool bPrivateSectionCommentIsWritten;
-
     void writeOperations(UMLClassifier *c, QTextStream &perl);
     void writeOperations(const QString &classname, UMLOperationList &opList,
                          QTextStream &perl);
