@@ -1,14 +1,9 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2005                                                    *
- *   Richard Dale  <Richard_Dale@tipitina.demon.co.uk>                     *
- *   copyright (C) 2006-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2005 Richard Dale <Richard_Dale@tipitina.demon.co.uk>
+    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "rubyclassifiercodedocument.h"
@@ -184,9 +179,9 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
 
                 if (name == QLatin1String("codecomment")) {
                     CodeComment * block = new RubyCodeComment(this);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeComment to :"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeComment to :"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -197,25 +192,25 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     // search for our method in the
                     TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                     if (!tb || !addTextBlock(tb)) {
-                        uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeclassfield child method to:"<<this;
                         // DON'T delete
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblock")) {
                     CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeBlock to :"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblockwithcomments")) {
                     CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeBlockwithcomments to:"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -224,7 +219,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     // do nothing.. this is treated elsewhere
                 } else if (name == QLatin1String("hierarchicalcodeblock")) {
                     HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
                         delete block;
@@ -235,10 +230,10 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     // find the code operation by id
                     QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
                     UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                    UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                    UMLOperation * op = obj->asUMLOperation();
                     if (op) {
                         CodeOperation * block = new RubyCodeOperation(this, op);
-                        block->loadFromXMI(element);
+                        block->loadFromXMI1(element);
                         if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
                         } else {
@@ -250,7 +245,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     }
                 } else if (name == QLatin1String("rubyclassdeclarationblock")) {
                     RubyClassDeclarationBlock * block = getClassDecl();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add ruby code declaration block to:"<<this;
                         // DON'T delete.
@@ -307,7 +302,7 @@ void RubyClassifierCodeDocument::resetTextBlocks()
 // based on the parent classifier object.
 // For any situation in which this is called, we are either building the code
 // document up, or replacing/regenerating the existing auto-generated parts. As
-// such, we will want to insert everything we resonablely will want
+// such, we will want to insert everything we reasonably will want
 // during creation. We can set various parts of the document (esp. the
 // comments) to appear or not, as needed.
 void RubyClassifierCodeDocument::updateContent()
@@ -353,7 +348,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     bool isInterface = parentIsInterface();
     bool hasOperationMethods = false;
-    Q_ASSERT(c != NULL);
+    Q_ASSERT(c != 0);
     if (c) {
         UMLOperationList list = c->getOpList();
         hasOperationMethods = ! list.isEmpty();
@@ -470,7 +465,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // public
     pubConstructorBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
-    // special condiions for showing comment: only when autogenerateding empty constructors
+    // special conditions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * pubConstComment = pubConstructorBlock->getComment();
     if (!forceDoc && (isInterface || !pol->getAutoGenerateConstructors()))
@@ -480,7 +475,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // protected
     protConstructorBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
-    // special condiions for showing comment: only when autogenerateding empty constructors
+    // special conditions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * protConstComment = protConstructorBlock->getComment();
     if (!forceDoc && (isInterface || !pol->getAutoGenerateConstructors()))
@@ -490,7 +485,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // private
     privConstructorBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
-    // special condiions for showing comment: only when autogenerateding empty constructors
+    // special conditions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * privConstComment = privConstructorBlock->getComment();
     if (!forceDoc && (isInterface || !pol->getAutoGenerateConstructors()))
