@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *  copyright (C) 2003-2014                                                *
- *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 #include "umluniqueconstraintdialog.h"
 
 #include "attribute.h"
@@ -127,12 +122,12 @@ void UMLUniqueConstraintDialog::setupDialog()
     comboButtonHBoxLayout->addWidget(buttonBox);
 
     // We first insert all attributes to the combo box
-    UMLEntity* ue = static_cast<UMLEntity*>(m_pUniqueConstraint->parent());
+    UMLEntity* ue = m_pUniqueConstraint->umlParent()->asUMLEntity();
     uDebug() << ue;
     if (ue) {
        UMLClassifierListItemList ual = ue->getFilteredList(UMLObject::ot_EntityAttribute);
        foreach(UMLClassifierListItem* att, ual) {
-           m_pEntityAttributeList.append(static_cast<UMLEntityAttribute*>(att));
+           m_pEntityAttributeList.append(att->asUMLEntityAttribute());
            m_pAttributeCB->addItem(att->toString(Uml::SignatureType::SigNoVis));
        }
     }
@@ -247,6 +242,9 @@ bool UMLUniqueConstraintDialog::apply()
     // set name
     m_pUniqueConstraint->setName(name);
 
+    // propagate changes to tree view
+    m_pUniqueConstraint->emitModified();
+
     return true;
 }
 
