@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2002-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "docwindow.h"
@@ -152,7 +147,7 @@ void DocWindow::showDocumentation(UMLObject * object, bool overwrite)
     m_pUMLObject = object;
     m_docTE->setText(m_pUMLObject->doc());
     if (m_pUMLObject->baseType() == UMLObject::ot_Folder) {
-        UMLFolder *folder = dynamic_cast<UMLFolder*>(m_pUMLObject);
+        UMLFolder *folder = m_pUMLObject->asUMLFolder();
         updateLabel(folder->localName());
     }
     else
@@ -244,10 +239,7 @@ void DocWindow::showDocumentation(AssociationWidget * widget, bool overwrite)
         return;
     }
     if (widget == m_pAssocWidget) {
-        if (overwrite) {
-            updateDocumentation(true);
-        }
-        else {
+        if (!overwrite) {
             return;
         }
     }
@@ -285,6 +277,7 @@ void DocWindow::updateDocumentation(bool clear, bool startup)
             m_pUMLScene->setDocumentation(m_docTE->toPlainText());
         } else if (m_Showing == st_UMLWidget &&  m_pUMLWidget) {
             m_pUMLWidget->setDocumentation(m_docTE->toPlainText());
+            m_pUMLWidget->updateGeometry();
         } else if (m_Showing == st_Association &&  m_pAssocWidget) {
             m_pAssocWidget->setDocumentation(m_docTE->toPlainText());
         } else if (m_Showing == st_Project) {
@@ -429,28 +422,26 @@ void DocWindow::slotFocusEnabledChanged(int status)
  */
 void DocWindow::updateLabel(const QString& name)
 {
-    if (!name.isEmpty()) {
-        Icon_Utils::IconType icon = Icon_Utils::it_Home;
-        switch (m_Showing) {
-        case st_Project:
-            icon = Icon_Utils::it_Code_Gen_Wizard;
-            break;
-        case st_UMLScene:
-            icon = Icon_Utils::it_Diagram_Class;
-            break;
-        case st_UMLObject:
-            icon = Icon_Utils::it_Object;
-            break;
-        case st_UMLWidget:
-            icon = Icon_Utils::it_Class;
-            break;
-        case st_Association:
-            icon = Icon_Utils::it_Association;
-            break;
-        }
-        m_typeLabel->setPixmap(Icon_Utils::SmallIcon(icon));
-        m_nameLabel->setText(name);
+    Icon_Utils::IconType icon = Icon_Utils::it_Home;
+    switch (m_Showing) {
+    case st_Project:
+        icon = Icon_Utils::it_Code_Gen_Wizard;
+        break;
+    case st_UMLScene:
+        icon = Icon_Utils::it_Diagram_Class;
+        break;
+    case st_UMLObject:
+        icon = UMLObject::toIcon(m_pUMLObject->baseType());
+        break;
+    case st_UMLWidget:
+        icon = WidgetBase::toIcon(m_pUMLWidget->baseType());
+        break;
+    case st_Association:
+        icon = Icon_Utils::it_Association;
+        break;
     }
+    m_typeLabel->setPixmap(Icon_Utils::SmallIcon(icon));
+    m_nameLabel->setText(name);
     m_modifiedWidget->setModified(isModified());
 }
 
